import { FC } from 'react';
import { FunctionComponent } from 'react';
import { SVGProps } from 'react';

declare const categories: {
    readonly entrance: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly selectors: readonly ["entrance=yes"];
        readonly hide: true;
    };
    readonly emergency_exit: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly selectors: readonly ["entrance=emergency"];
        readonly hide: true;
    };
    readonly exit: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly selectors: readonly ["entrance=exit"];
        readonly hide: true;
    };
    readonly main_entrance: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly selectors: readonly ["entrance=main"];
        readonly hide: true;
    };
    readonly subway_entrance: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["railway=subway_entrance"];
    };
    readonly tourism: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly selectors: readonly ["tourism=*"];
        readonly synonyms: readonly ["350-3500-0304", "350-3510-0236", "350-3510-0237", "350-3522-0239", "350-3550-0336", "500-5510-0374", "550-5510-0000", "550-5510-0349", "550-5510-0357", "550-5510-0358", "550-5510-0359", "550-5510-0382", "550-5510-0383", "550-5510-0384", "550-5510-0385", "700-7460-0115", "900-9200-0000", "900-9200-0301", "Bicycle Trailhead", "Bike Trail", "Conference", "Convention", "Cross-country Skiing Trailhead", "Hiking Trailhead", "Horse Riding Trailhead", "Luggage Store", "Mountain Bike Trailhead", "Mountain Pass", "Nature Preserve", "Off-Road Vehicle Area", "Off-road Trailhead", "Pedestrian Plaza", "Rafting", "Summer Camp", "Tour Provider", "Tourismusinformationszentrum", "Tourist Information Center", "Tourist Information", "Trailhead", "Walking Path Trailhead", "tourism"];
    };
    readonly information: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["tourism", "accommodation", "public_transfer"];
        readonly selectors: readonly ["information=audioguide", "information=board", "information=guidepost", "information=map", "information=stele", "information=terminal"];
    };
    readonly animal: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["tourism", "leisure"];
        readonly selectors: readonly ["attraction=animal"];
    };
    readonly telephone: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["tourism", "shopping", "public_transfer"];
        readonly selectors: readonly ["amenity=telephone"];
    };
    readonly attraction: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["tourism"];
        readonly selectors: readonly ["tourism=attraction"];
        readonly synonyms: readonly ["300-3000-0000", "300-3000-0023", "300-3000-0231", "300-3000-0232", "350-3500-0235", "Flyover", "Island Hot Spring", "Landmark or Attraction", "Lighthouse", "Palace", "Sehenswürdigkeit", "Tourist Attraction", "Volcano", "Waterfall", "attraction", "tourist_information_center"];
    };
    readonly memorial: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["tourism"];
        readonly selectors: readonly ["historic=memorial"];
        readonly synonyms: readonly ["300-3000-0025", "Historical Monument", "Memorial Site", "Monument / Landmark", "Monument", "monument"];
    };
    readonly viewpoint: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["tourism"];
        readonly selectors: readonly ["tourism=viewpoint"];
        readonly synonyms: readonly ["350-3510-0238", "350-3520-0224", "400-4300-0308", "550-5510-0242", "900-9200-0386", "Aussichtspunkt", "Meeting Point", "Mountain Peak", "Scenic Area", "Scenic Lookout", "Undersea Feature", "Viewpoint", "Vineyard"];
    };
    readonly castle: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["tourism"];
        readonly selectors: readonly ["historic=castle"];
        readonly synonyms: readonly ["Castle"];
    };
    readonly beach: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["tourism"];
        readonly selectors: readonly ["natural=beach"];
        readonly synonyms: readonly ["550-5510-0205", "550-5510-0243", "Bay", "Beach", "Nudist Beach", "Surf Life Savings Club", "Surf Spot", "beach_resort"];
    };
    readonly cave: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["tourism"];
        readonly selectors: readonly ["natural=cave_entrance"];
        readonly synonyms: readonly ["Cave", "cave_entrance"];
    };
    readonly themepark: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["tourism"];
        readonly selectors: readonly ["tourism=theme_park"];
        readonly synonyms: readonly ["550-5520-0000", "550-5520-0207", "Theme Park Ride / Attraction", "Theme Park or Holiday Camp", "Theme Park", "amusement_park", "theme_park"];
    };
    readonly archaeological_site: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["tourism"];
        readonly selectors: readonly ["historic=archaeological_site"];
    };
    readonly toilets: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly selectors: readonly ["amenity=toilets"];
        readonly synonyms: readonly ["800-8700-0198", "Eurokey-Anlage", "Public Bathroom", "Public Toilet", "public_bathroom", "Öffentliche WC-Anlage"];
    };
    readonly sport: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly synonyms: readonly ["800-8600-0000", "800-8600-0191", "800-8600-0197", "Bowling Green", "Cycle Studio", "Disc Golf", "Go Kart Track", "Martial Arts Dojo", "Mini Golf", "Sports Activities", "bowling_alley", "sport"];
    };
    readonly sports_center: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["sport"];
        readonly selectors: readonly ["leisure=sports_centre", "leisure=sports_hall", "leisure=fitness_centre"];
        readonly synonyms: readonly ["550-5510-0203", "800-8600-0181", "800-8600-0183", "800-8600-0184", "800-8600-0185", "800-8600-0188", "800-8600-0190", "800-8600-0192", "800-8600-0193", "800-8600-0194", "800-8600-0199", "800-8600-0200", "800-8600-0314", "800-8600-0376", "800-8600-0377", "Athletics & Sports", "BMX Track", "Badminton", "Basketball Court", "Basketball", "Bike Park", "Bowling Alley", "Boxing Gym", "Climbing Gym", "College Gym", "College Rec Center", "Fitness or Health Club", "Golf Course", "Golf Practice Range", "Gym / Fitness Center", "Gym", "Gymnastics Gym", "Ice Skating Rink", "Indoor Skiing", "Indoor Sports", "Outdoor Gym", "Pilates Studio", "Public Sports Facility", "Rock Climbing Spot", "Rugby", "Shooting Gallery", "Ski Area", "Ski Chairlift", "Ski Trail", "Skydiving Drop Zone", "Sporthalle", "Sports Club", "Sports Facility or Venue", "Squash Court", "Squash Facility", "Tennis Club", "Volleyball Court", "Yoga Studio", "fitness_center", "gym", "sports_centre", "sports_complex"];
    };
    readonly stadium: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["sport"];
        readonly selectors: readonly ["leisure=stadium"];
        readonly synonyms: readonly ["800-8600-0180", "800-8600-0186", "800-8600-0187", "800-8600-0195", "800-8600-0381", "Baseball Stadium", "Basketball Stadium", "College Baseball Diamond", "College Basketball Court", "College Cricket Pitch", "College Hockey Rink", "College Stadium", "College Track", "Cricket Ground", "Curling Ice", "Eisstadion", "Football Stadium", "Golf Driving Range", "Hockey Arena", "Hockey Field", "Hockey Rink", "Ice Hockey", "Racetrack", "Racquetball Court", "Rugby Stadium", "Running Track", "Soccer Stadium", "Sports Complex or Stadium", "Sportstadion", "Stadium", "Tennis Stadium", "Track Stadium", "Track", "stadium"];
    };
    readonly soccer: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["sport"];
        readonly selectors: readonly ["leisure=pitch"];
        readonly synonyms: readonly ["800-8600-0189", "Badminton Court", "Baseball Field", "College Football Field", "College Soccer Field", "College Tennis Court", "Football pitch", "Outdoors & Recreation", "Soccer Field", "Tennis Court", "pitch"];
    };
    readonly swimming: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["sport"];
        readonly selectors: readonly ["amenity=swimming_pool", "leisure=swimming_pool"];
        readonly synonyms: readonly ["public_swimming_pool", "550-5520-0357", "800-8600-0182", "800-8600-0316", "Bathing Area", "Dive Spot", "Diving Centre", "Gym Pool", "Hotel Pool", "Pool", "Schwimmbad", "Swim School", "Swimming Pool", "Water Park", "swimming_pool"];
    };
    readonly shopping: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly selectors: readonly ["shop=*"];
        readonly synonyms: readonly ["600-6900-0000", "600-6900-0099", "600-6900-0249", "Baby Store", "Big Box Store", "Construction & Landscaping", "Dairy Store", "Duty-free Shop", "Fireworks Store", "General Merchandise", "Geschäfte", "Miscellaneous Shop", "Shop & Service", "cheese_shop", "luggage_store", "perfume_store", "shopping", "store"];
        readonly priority: 10;
    };
    readonly bicycle_repair: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["amenity=bicycle_repair_station"];
        readonly synonyms: readonly ["Bicycle Repair & Maintenance"];
    };
    readonly cemetery: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["landuse=cemetery"];
        readonly synonyms: readonly ["Cemetery"];
    };
    readonly supermarket: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=supermarket"];
        readonly synonyms: readonly ["600-6300-0066", "Food & Drink Shop", "Food Service", "Supermarket", "Turşucu", "grocery_or_supermarket", "grocery_store", "supermarket"];
    };
    readonly confectionery: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=confectionery"];
        readonly synonyms: readonly ["600-6300-0245", "Candy Store", "Chocolate Shop", "Cupcake Shop", "Dessert Shop", "Donut Shop", "Pastry Shop", "Pie Shop", "Sweet Shop", "confectionery"];
    };
    readonly erotic: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=erotic"];
        readonly synonyms: readonly ["600-6900-0305", "Adult Boutique", "Adult/Sex Shop", "Erotic Museum"];
    };
    readonly funeral_home: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=funeral_directors"];
        readonly synonyms: readonly ["700-7400-0142", "800-8700-0166", "800-8700-0167", "Crematorium", "Funeral Home", "funeral_directors", "funeral_home"];
    };
    readonly mall: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=mall"];
        readonly synonyms: readonly ["600-6100-0062", "Einkaufszentrum", "Mall or Shopping Centre", "Mall", "Shopping Center", "Shopping Centre", "Shopping Mall", "Shopping Plaza", "shopping_center", "shopping_mall"];
    };
    readonly music: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=music"];
        readonly synonyms: readonly ["600-6900-0105", "CD & Video Sales", "Music Store", "Record Shop", "Vinyl"];
    };
    readonly organic_food: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=organic"];
        readonly synonyms: readonly ["Health Food Store", "Organic Grocery", "organic"];
    };
    readonly pet_store: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=pet"];
        readonly synonyms: readonly ["600-6900-0097", "700-7400-0293", "Pet Care Service", "Pet Store", "Pet Supplies", "pet", "pet_store", "pet_supply_store"];
    };
    readonly greengrocer: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=greengrocer"];
        readonly synonyms: readonly ["Fruit & Vegetable Store", "Grocery Store", "green_grocers"];
    };
    readonly tobacco: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=tobacco"];
        readonly synonyms: readonly ["Marijuana Dispensary", "Smoke Shop", "Vape Store", "tobacco_shop"];
    };
    readonly bicycle_store: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=bicycle"];
        readonly synonyms: readonly ["500-5500-0387", "550-5510-0387", "600-6900-0246", "700-7400-0281", "Bicycle & Accessories Shop", "Bicycle Service", "Bike Shop", "bicycle", "bicycle_store"];
    };
    readonly computers: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=computer", "office=it"];
        readonly synonyms: readonly ["600-6500-0075", "700-7200-0261", "Computer Hardware & Software", "IT & Office Equipment Services", "IT Services", "computer"];
    };
    readonly sports_shop: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=sports"];
        readonly synonyms: readonly ["600-6900-0094", "600-6900-0389", "600-6900-0390", "600-6900-0391", "600-6900-0392", "600-6900-0393", "600-6900-0397", "800-8600-0196", "Board Shop", "Cross-country Ski Shop", "Running/Walking Shop", "Skate Shop", "Ski Shop", "Snowboard Shop", "Sport", "Sporting Goods Shop", "Sporting Goods Store", "Surf Shop", "sporting_goods_store", "sports"];
    };
    readonly hiking: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=outdoor"];
        readonly synonyms: readonly ["550-5510-0379", "600-6900-0388", "600-6900-0394", "600-6900-0395", "600-6900-0396", "600-6900-0398", "BMX Shop", "Camping/Hiking Shop", "Canoe/Kayak Shop", "Dive Shop", "Hunting Supply", "Hunting/Fishing Shop", "Outdoor Services", "Outdoor Supply Store", "Tack Shop", "outdoor"];
    };
    readonly kiosk: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=kiosk"];
        readonly synonyms: readonly ["700-7400-0291", "Lottery Retailer", "Self-Service Kiosk"];
    };
    readonly mobile_phones: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=mobile_phone", "shop=telecommunication"];
        readonly synonyms: readonly ["600-6500-0073", "600-6500-0074", "Mobile Phone Retailer", "Mobile Phone Service & Repair", "Mobile Phone Shop", "cell_phone_store", "mobile_phone"];
    };
    readonly newsagent: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=newsagent"];
        readonly synonyms: readonly ["Newsstand"];
    };
    readonly tailor: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=tailor"];
        readonly synonyms: readonly ["700-7400-0149", "Tailor Shop", "Tailoring & Alteration"];
    };
    readonly tea_shop: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=tea"];
        readonly synonyms: readonly ["100-1100-0331", "Bubble Tea Shop", "Tea Room", "tea", "tea_house"];
    };
    readonly textiles: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=fabric"];
        readonly synonyms: readonly ["Fabric Shop", "fabric"];
    };
    readonly video_store: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=video"];
        readonly synonyms: readonly ["600-6900-0106", "Video & Game Rental", "Video Store", "movie_rental", "movie_rental_store", "music_store", "video"];
    };
    readonly art_shop: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=art"];
        readonly synonyms: readonly ["Arts & Crafts Store"];
    };
    readonly car_repair: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=car_repair"];
        readonly synonyms: readonly ["600-6900-0248", "700-7200-0268", "700-7200-0278", "700-7850-0000", "700-7850-0121", "700-7850-0122", "700-7850-0123", "700-7850-0124", "700-7850-0125", "700-7850-0126", "700-7850-0127", "700-7850-0128", "700-7850-0129", "700-7900-0323", "Auto Garage", "Auto Parts", "Auto Workshop", "Automotive Services", "Car Repair or Service", "Car Repair", "Car Wash", "Car Washing & Detailing", "Motorcycle Accessories", "Motorcycle Service & Maintenance", "Motorcycle Shop", "Roadside Assistance", "Towing Service", "Truck Repair", "Truck Washing", "Tyre Repair", "Van Repair", "Vehicle Emissions Testing", "car_repair", "car_wash"];
    };
    readonly variety_store: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=variety_store"];
        readonly synonyms: readonly ["600-6900-0096", "600-6900-0100", "600-6900-0102", "Discount Store", "Outlet Mall", "Outlet Store", "Speciality Store", "Stoop Sale", "Variety Store"];
    };
    readonly photography: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=photo"];
        readonly synonyms: readonly ["700-7400-0144", "Camera Store", "Photographic Services", "Photography Lab", "Photography Studio", "Spectacle", "photo", "photo_lab"];
    };
    readonly diy: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=doityourself"];
        readonly synonyms: readonly ["600-6600-0077", "600-6900-0307", "Handicraft Supplies", "Hardware Shop or DIY Centre", "Hobby Shop", "Knitting Store", "doityourself", "home_improvement_store"];
    };
    readonly beverages: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=beverages"];
    };
    readonly beautysalon: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=beauty", "shop=tattoo", "amenity=tanning_salon"];
        readonly synonyms: readonly ["600-6900-0104", "600-6950-0000", "600-6950-0399", "600-6950-0400", "600-6950-0401", "700-7400-0283", "700-7400-0284", "700-7400-0343", "Barber", "Body Piercing & Tattoos", "Hair & Beauty", "Hair Salon", "Hair and Beauty", "Health & Beauty Service", "Nail Salon", "Piercing Parlor", "Tanning Salon", "Tattoo Parlor", "Wedding & Bridal Services", "beauty", "beauty_salon", "tattoo"];
    };
    readonly tools: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=hardware"];
        readonly synonyms: readonly ["600-6600-0000", "600-6600-0084", "600-6600-0310", "600-6600-0319", "Hardware Store", "Hardware", "Home & Garden", "Locksmith", "Paint & Decorating Supplies", "Power Equipment Dealer", "Timber Merchants & Supplies", "hardware", "hardware_store", "locksmith"];
    };
    readonly deli: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=deli"];
        readonly synonyms: readonly ["600-6300-0064", "600-6300-0067", "Cheese Shop", "Deli / Bodega", "Fishing Store", "Gourmet Shop", "Herbs & Spices Store", "Smoothie Shop", "Souvlaki Shop", "Specialty Food & Beverage", "Specialty Food Store", "deli"];
    };
    readonly travel_agency: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=travel_agency"];
        readonly synonyms: readonly ["General Travel", "Reisebüro", "Travel & Transport", "Travel Agency & Tickets", "Travel Agency", "travel_agency"];
    };
    readonly stationery: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=stationery"];
        readonly synonyms: readonly ["600-6900-0095", "Office Supplies & Services", "Paper / Office Supplies Store", "Stationery Store"];
    };
    readonly copyshop: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=copyshop"];
        readonly synonyms: readonly ["copy_shop", "Print Shop"];
    };
    readonly interior_decoration: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=interior_decoration"];
        readonly synonyms: readonly ["600-6600-0078", "600-6600-0079", "600-6600-0083", "Flooring & Carpet", "Frame Store", "Glaziers/Window Fitters", "Home Speciality Store", "art"];
    };
    readonly "2nd_hand": {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=second_hand"];
        readonly synonyms: readonly ["600-6900-0251", "Second-hand Shop", "Thrift / Vintage Store", "second_hand"];
    };
    readonly toys: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=toys"];
        readonly synonyms: readonly ["600-6900-0358", "Toy / Game Store", "Toy Shop", "Video Game Store", "toy_store"];
    };
    readonly laundry: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=laundry"];
        readonly synonyms: readonly ["700-7400-0137", "Dry Cleaning & Laundry", "Laundromat", "Laundry Service", "laundry"];
    };
    readonly butcher: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping", "food"];
        readonly selectors: readonly ["shop=butcher"];
        readonly synonyms: readonly ["600-6300-0363", "Butcher", "Butcher's", "Sausage Shop", "butcher_shop"];
    };
    readonly bread: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping", "food"];
        readonly selectors: readonly ["shop=bakery"];
        readonly synonyms: readonly ["600-6300-0244", "Bagel Shop", "Baker's", "Bakery", "bakery"];
    };
    readonly alcohol: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=alcohol"];
        readonly synonyms: readonly ["600-6300-0068", "Beer Store", "Distillery", "Liquor Store", "Wine & Spirits", "Wine Shop", "Winery", "liquor_store", "wine_store"];
    };
    readonly garden_center: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=garden_centre"];
        readonly synonyms: readonly ["600-6600-0082", "Garden Center", "Garden Centre", "garden_centre"];
    };
    readonly antiques: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=antiques"];
        readonly synonyms: readonly ["antique_furniture_store", "Antique Shop"];
    };
    readonly market: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["amenity=marketplace"];
        readonly synonyms: readonly ["100-1000-0004", "600-6900-0247", "Christmas Market", "Fair", "Farmers Market", "Fish Market", "Flea Market", "Floating Market", "Market Stall with Food", "Market", "Night Market", "Street Fair", "bazaar", "market", "seafood_market"];
    };
    readonly gifts: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=gift"];
        readonly synonyms: readonly ["600-6900-0103", "Antiques & Art", "Gift Shop", "Gifts", "Souvenir Shop", "gift"];
    };
    readonly flowers: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=florist"];
        readonly synonyms: readonly ["600-6900-0355", "Florist", "Flower Shop", "florist"];
    };
    readonly dry_cleaning: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=dry_cleaning"];
        readonly synonyms: readonly ["Dry Cleaner"];
    };
    readonly department_store: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=department_store"];
        readonly synonyms: readonly ["600-6200-0063", "600-6900-0098", "Department Store", "Warehouse Store", "Warehouse or Wholesaler", "Warehouse", "department_store"];
    };
    readonly convenience_store: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=convenience"];
        readonly synonyms: readonly ["600-6000-0000", "600-6000-0061", "600-6300-0364", "Convenience Store", "Dairy Products", "Other Convenience Store", "chocolate_shop", "convenience", "convenience_store"];
    };
    readonly books: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=books"];
        readonly synonyms: readonly ["600-6700-0000", "600-6700-0087", "Book Shop", "Bookstore", "College Bookstore", "College Library", "Comic Shop", "Other Book Shop", "Used Bookstore", "book_store", "librairie_papeterie"];
    };
    readonly barber: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=hairdresser"];
        readonly synonyms: readonly ["Salon / Barbershop", "hair_care", "hair_salon", "hairdresser"];
    };
    readonly electronics: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=electronics"];
        readonly synonyms: readonly ["600-6500-0072", "600-6500-0076", "600-6500-0333", "600-6600-0085", "700-7400-0146", "700-7400-0365", "Consumer Electronics Store", "Electrical Repair", "Electronics Store", "Electronics", "Entertainment Electronics", "Large Domestic Appliances", "Repair Services", "Watch Shop", "appliance_store", "electronics_store"];
    };
    readonly instruments: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=musical_instrument"];
        readonly synonyms: readonly ["musical_instrument"];
    };
    readonly jewelry: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=jewelry"];
        readonly synonyms: readonly ["600-6900-0101", "600-6900-0356", "Flowers & Jewelry", "Jeweller", "Jewelry Store", "jewelry_store"];
    };
    readonly shoes: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=shoes"];
        readonly synonyms: readonly ["600-6800-0092", "Shoe Repair", "Shoe Store", "Shoes & Footwear", "boot_store", "shoe_store"];
    };
    readonly car_dealer: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=car"];
        readonly synonyms: readonly ["700-7800-0118", "700-7800-0119", "700-7800-0120", "700-7900-0000", "700-7900-0130", "Auto Dealership", "Automotive Shop", "Motorcycle Dealership", "New Car Dealership", "Truck Dealership", "Truck Sales & Service", "Used Car Dealership", "car_dealer", "car_shop"];
    };
    readonly clothes: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=clothes"];
        readonly synonyms: readonly ["600-6800-0000", "600-6800-0089", "600-6800-0090", "600-6800-0091", "600-6800-0093", "Accessories Store", "Batik Shop", "Boutique", "Bridal Shop", "Children's Clothing", "Clothing & Accessories", "Clothing Store", "Costume Shop", "Kids Store", "Leather Goods Store", "Lingerie Store", "Men's Clothing", "Men's Store", "Specialty Clothing Store", "Women's Clothing", "Women's Store", "clothing_store"];
    };
    readonly furniture: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=furniture"];
        readonly synonyms: readonly ["600-6600-0080", "Carpet Store", "Furniture & Home Accessories", "Furniture / Home Store", "Kitchen Supply Store", "Lighting Store", "Mattress Store", "furniture_store", "home_goods_store"];
    };
    readonly chemist: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["shopping"];
        readonly selectors: readonly ["shop=chemist"];
        readonly synonyms: readonly ["600-6400-0069", "Chemist's", "Cosmetics Shop", "Drugstore"];
    };
    readonly public_transfer: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly synonyms: readonly ["400-4100-0040", "400-4100-0041", "400-4100-0042", "400-4100-0043", "400-4100-0047", "400-4100-0226", "400-4100-0326", "400-4100-0348", "400-4200-0048", "400-4200-0049", "400-4200-0240", "400-4200-0241", "400-4200-0311", "400-4200-0312", "400-4200-0313", "550-5510-0227", "800-8500-0179", "Bicycle Parking", "Bridge", "Canal Lock", "Canal", "Cargo Centre", "Cargo Transport", "Courier Service", "Goods Entrance", "Intersection", "Loading Bay", "Loading Dock", "Local or Regional Public Transport", "Motorway Exit", "Public Transport Access", "Public Transport Stop", "Road", "Ski Lift", "Toll Booth", "Toll Plaza", "Tollbooth", "Transport Service", "Transportation Service", "Tunnel", "Verkehr", "Weighbridge", "public_transfer"];
        readonly priority: 30;
    };
    readonly station: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["public_transport=station"];
    };
    readonly boarding_area: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
    };
    readonly train: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["railway=halt"];
        readonly synonyms: readonly ["400-4100-0339", "400-4100-0340", "Aerial Tramway", "Cable Car", "Monorail", "halt", "train_station"];
    };
    readonly cablecar: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["aerialway=station", "aerialway=cable_car", "aerialway=gondola"];
        readonly synonyms: readonly ["Bergbahnen", "cable_car"];
    };
    readonly stop_area: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["public_transport=stop_area"];
        readonly synonyms: readonly ["stop_area"];
    };
    readonly stop_position: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["public_transport=stop_position"];
        readonly synonyms: readonly ["stop_position"];
    };
    readonly platform: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["public_transport=platform"];
        readonly synonyms: readonly ["Platform", "Tram- oder Bushaltestelle", "platform"];
    };
    readonly railway_platform: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["railway=platform"];
    };
    readonly shelter: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["amenity=shelter"];
    };
    readonly tram_crossing: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["railway=tram_crossing"];
    };
    readonly traffic_signals: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["crossing=traffic_signals"];
    };
    readonly parking: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly synonyms: readonly ["Park & Ride"];
    };
    readonly parking_carports: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["parking=carports"];
    };
    readonly parking_half_on_kerb: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["parking=half_on_kerb"];
    };
    readonly parking_layby: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["parking=layby"];
    };
    readonly parking_multi_storey: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["parking=multi_storey"];
    };
    readonly parking_on_kerb: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["parking=on_kerb"];
    };
    readonly parking_rooftop: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["parking=rooftop"];
    };
    readonly parking_street_side: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["parking=street_side"];
    };
    readonly parking_surface: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["parking=surface"];
    };
    readonly parking_underground: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["parking=underground"];
    };
    readonly taxi: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["amenity=taxi"];
        readonly synonyms: readonly ["Taxi Rank", "Taxi Stand", "Taxi", "taxi_service", "taxi_stand"];
    };
    readonly pier: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["man_made=pier"];
        readonly synonyms: readonly ["Pier"];
    };
    readonly charging_station: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["amenity=charging_station"];
        readonly synonyms: readonly ["EV Charging Point", "EV Charging Station"];
    };
    readonly marina: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["leisure=marina"];
        readonly synonyms: readonly ["350-3500-0300", "400-4200-0051", "700-7400-0140", "900-9200-0219", "Bay or Harbour", "Boat Rental", "Boat or Ferry", "Boating Services", "Cruise", "Harbor / Marina", "Harbor", "Harbour", "Marina", "Port", "Seaport or Harbour", "Seaport", "boatyard"];
    };
    readonly bicycle_rental: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["amenity=bicycle_rental"];
        readonly synonyms: readonly ["400-4100-0347", "Bicycle Sharing Docking Station", "Bike Rental / Bike Share"];
    };
    readonly bus_stop: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["platform"];
        readonly selectors: readonly ["highway=bus_stop"];
        readonly synonyms: readonly ["400-4100-0036", "400-4100-0341", "Bus Rapid Transit", "Bus Stop", "transit_station"];
    };
    readonly subway_station: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly synonyms: readonly ["400-4100-0037", "Metro Station", "Underground/Metro", "subway_station"];
    };
    readonly fuel: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["amenity=fuel"];
        readonly synonyms: readonly ["700-7600-0000", "700-7600-0116", "700-7600-0322", "Gas Station", "Petrol Station", "Service Station", "Tankstelle", "gas_station"];
    };
    readonly ferry: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["amenity=ferry_terminal"];
        readonly synonyms: readonly ["400-4100-0044", "400-4100-0045", "400-4100-0046", "400-4100-0338", "Ferry Terminal", "Ferry", "Train Ferry", "Water Taxi", "ferry_terminal"];
    };
    readonly car_rental: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["amenity=car_rental"];
        readonly synonyms: readonly ["700-7851-0117", "Car Hire Agency", "Rental Car Location", "car_rental"];
    };
    readonly car_sharing: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["amenity=car_sharing"];
    };
    readonly tram_stop: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["railway=tram_stop"];
        readonly synonyms: readonly ["400-4100-0342", "Funicular", "Light Rail", "Tram Station"];
    };
    readonly bus_station: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["amenity=bus_station"];
        readonly synonyms: readonly ["bus_station", "Bus Line", "Bus Station"];
    };
    readonly train_station: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["railway=station"];
        readonly synonyms: readonly ["400-4100-0035", "400-4100-0038", "400-4100-0039", "400-4200-0050", "Bahnhof", "Commuter Rail Station", "Commuter Train", "Light Rail Station", "Railway Station", "Railway Yard", "Train Station", "Train", "station"];
    };
    readonly airport: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["public_transfer"];
        readonly selectors: readonly ["aeroway=terminal"];
        readonly synonyms: readonly ["400-4000-4580", "400-4000-4581", "400-4000-4582", "400-4200-0052", "Airport Cargo Centre", "Airport Food Court", "Airport Gate", "Airport Lounge", "Airport Service", "Airport Terminal", "Airport Tram", "Airport", "Baggage Claim", "Baggage Locker", "Heliport", "Plane", "Public Sports Airport", "airport", "terminal"];
    };
    readonly unknown: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly hide: true;
    };
    readonly elevator: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly selectors: readonly ["highway=elevator"];
        readonly synonyms: readonly ["Aufzug", "Fahrstuhl", "lift"];
        readonly hide: true;
    };
    readonly escalator: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly synonyms: readonly ["Rolltreppe", "moving staircase", "moving stairway"];
        readonly hide: true;
    };
    readonly other: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly hide: true;
        readonly synonyms: readonly ["800-8700-0000", "900-9100-0215", "900-9100-0216", "Astrologer", "Building", "Farm", "Field", "Forest", "Fountain", "Gun Shop", "Home (private)", "Island", "Lake", "Mountain", "Moving Target", "Other Repair Shop", "Pawn Shop", "Plaza", "Pop-Up Shop", "Reservoir", "River", "Stables", "Supplement Shop", "Trail", "Tree", "Waterfront", "Well", "electrician", "establishment", "general_contractor", "misc", "moving_company", "painter", "plumber", "roofing_contractor", "storage"];
    };
    readonly youth_organization: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["other"];
        readonly selectors: readonly ["community_centre=youth_centre"];
        readonly synonyms: readonly ["Youth Organizations"];
    };
    readonly tax_advisor: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["other"];
        readonly selectors: readonly ["office=tax_advisor"];
        readonly synonyms: readonly ["700-7400-0150", "Tax Services"];
    };
    readonly recycling: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["other"];
        readonly selectors: readonly ["amenity=recycling", "amenity=waste_basket", "amenity=waste_disposal"];
        readonly synonyms: readonly ["Recycling Facility", "Recycling- Sammelstelle"];
    };
    readonly vending_machine: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["other", "public_transfer", "leisure"];
        readonly selectors: readonly ["amenity=vending_machine"];
    };
    readonly house: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["other"];
        readonly selectors: readonly ["office=estate_agent"];
        readonly synonyms: readonly ["700-7200-0273", "700-7200-0324", "700-7200-0344", "700-7400-0145", "Estate Agency", "Flat Rental Service", "Housing Development", "Property Management", "Real Estate Office", "Real Estate and Brokers", "estate_agent", "real_estate_agency"];
    };
    readonly veterinary: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["other"];
        readonly selectors: readonly ["amenity=veterinary"];
        readonly synonyms: readonly ["Pet Servic", "Veterinarian", "Veterinary Medicine", "veterinarian", "veterinary_care"];
    };
    readonly association: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["other"];
        readonly selectors: readonly ["office=association"];
        readonly synonyms: readonly ["700-7200-0269", "Organisation or Society", "association_or_organization"];
    };
    readonly industry: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["other"];
        readonly synonyms: readonly ["700-7200-0265", "700-7200-0266", "700-7200-0275", "700-7400-0148", "900-9200-0218", "Distribution Center", "Factory", "Industrial Estate", "Manufacturing", "Mining", "Power Plant", "Repair & Maintenance Services", "Shipping Store", "Storage Facility", "Storage", "Waste Facility"];
    };
    readonly ngo: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["other"];
        readonly selectors: readonly ["office=ngo"];
        readonly synonyms: readonly ["Non-Profit"];
    };
    readonly insurance: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["other"];
        readonly selectors: readonly ["office=insurance"];
        readonly synonyms: readonly ["Insurance Office", "insurance_agency", "unemployment_office"];
    };
    readonly lawyer: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["other"];
        readonly selectors: readonly ["office=lawyer"];
        readonly synonyms: readonly ["700-7400-0138", "700-7400-0327", "Financial or Legal Service", "Lawyer", "Legal Services", "Solicitors", "lawyer"];
    };
    readonly company: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["other"];
        readonly selectors: readonly ["office=company", "office=*"];
        readonly synonyms: readonly ["700-7100-0000", "700-7100-0134", "700-7200-0000", "700-7200-0252", "700-7200-0254", "700-7200-0255", "700-7200-0256", "700-7200-0257", "700-7200-0260", "700-7200-0262", "700-7200-0263", "700-7200-0264", "700-7200-0274", "700-7200-0276", "700-7200-0277", "700-7200-0279", "700-7200-0328", "700-7200-0329", "700-7200-0330", "700-7200-0342", "700-7200-0345", "700-7250-0136", "700-7400-0000", "700-7400-0141", "700-7400-0143", "700-7400-0151", "700-7400-0152", "700-7400-0282", "700-7400-0287", "700-7400-0288", "700-7400-0290", "700-7400-0352", "700-7400-0366", "800-8700-0297", "900-9300-0335", "Advertising Agency", "Advertising", "Aviation Services", "B2B Services", "Bill Payment Service", "Business Area", "Business Facility", "Business Services", "Cleaning Services", "Commerce", "Commercial Services", "Communications & Media", "Conference Room", "Construction", "Corporate Amenity", "Coworking Space", "Customer Care Centre", "Design Studio", "Engineering & Scientific Services", "Event Service", "Financial Investment Firm", "Interior & Exterior Design", "Investigative & Detective Services", "Laboratory", "Landscaping Services", "Locksmiths & Security Systems Services", "Management & Consulting Services", "Marketing", "Marriage & Match-making Service", "Office", "Offices", "PR & Market Research", "Plumbers", "Printing & Publishing", "Professional & Other Places", "Radio Station", "Recording Studio", "Recycling Centre", "Removers", "Rental & Leasing", "Rental Service", "Research Station", "Restaurant Commercial Services", "Specialty Trade Contractors", "TV Station", "Tech Startup", "Telephone Service", "Translation & Interpreter Services", "Utilities", "Waste Removal & Sanitation", "corporate_office"];
    };
    readonly money_post: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly synonyms: readonly ["600-6900-0250", "700-7050-0109", "700-7200-0271", "Finance & Insurance Services", "Money Transferring Service", "Pawnshop", "accounting", "finance", "money_post"];
    };
    readonly post_box: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["money_post"];
        readonly selectors: readonly ["amenity=post_box"];
        readonly synonyms: readonly ["post_box", "Post box"];
    };
    readonly currencyexchange: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["money_post"];
        readonly selectors: readonly ["amenity=bureau_de_change"];
        readonly synonyms: readonly ["700-7050-0110", "Check Cashing Service", "Cheque Cashing & Currency Exchange", "Currency Exchange", "bureau_de_change"];
    };
    readonly parcel_locker: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["money_post"];
        readonly selectors: readonly ["amenity=parcel_locker"];
    };
    readonly bank: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["money_post"];
        readonly selectors: readonly ["amenity=bank"];
        readonly synonyms: readonly ["700-7000-0107", "Bank", "Credit Union", "bank"];
    };
    readonly post_office: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["money_post"];
        readonly selectors: readonly ["amenity=post_office"];
        readonly synonyms: readonly ["700-7450-0114", "700-7450-0294", "Post Office", "Post", "post_office"];
    };
    readonly atm: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["money_post"];
        readonly selectors: readonly ["amenity=atm"];
        readonly synonyms: readonly ["700-7010-0108", "ATM", "Cash Machine", "Geldautomat", "atm"];
    };
    readonly leisure: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly priority: 40;
        readonly selectors: readonly ["leisure=*"];
        readonly synonyms: readonly ["200-2000-0015", "200-2000-0016", "200-2000-0017", "200-2000-0018", "550-5510-0206", "700-7200-0270", "700-7400-0292", "800-8700-0296", "Amusement Arcade", "Arcade", "Betting Shop", "Bien-être", "Billiards", "Circus School", "Circus", "Clubhouse", "Comedy Club", "Entertainment & Recreation", "Entertainment Service", "Event School", "Event Space", "Event", "Festival", "Fishing Spot", "Gaming Cafe", "General Entertainment", "Gun Rang", "Laser Tag", "Line / Queue", "Live Entertainment or Music", "Loisir", "Lottery Ticket Sales", "Other Event", "Other Great Outdoors", "Outdoor Event Space", "Pachinko Parlor", "Paintball Field", "Parade", "Pool Hall", "Pool or Snooker", "Racecourse", "Recreation Centre", "Resort", "Rest Area", "Roller Rink", "Roof Deck", "Salsa Club", "Samba", "Skate Park", "Skating Rink", "Wellness Centre & Services", "circus"];
    };
    readonly outdoor_seating: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["leisure"];
        readonly selectors: readonly ["leisure=outdoor_seating"];
    };
    readonly dog_park: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["leisure"];
        readonly selectors: readonly ["leisure=dog_park"];
        readonly synonyms: readonly ["Dog park", "Dog Run"];
    };
    readonly shower: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["accommodation", "leisure", "public_transfer"];
        readonly selectors: readonly ["amenity=shower"];
        readonly synonyms: readonly ["shower"];
    };
    readonly picnic_table: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["leisure", "tourism"];
        readonly selectors: readonly ["leisure=picnic_table"];
    };
    readonly allotments: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["leisure"];
        readonly selectors: readonly ["landuse=allotments"];
    };
    readonly bbq: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["tourism", "leisure"];
        readonly selectors: readonly ["amenity=bbq"];
    };
    readonly cinema: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["leisure"];
        readonly selectors: readonly ["amenity=cinema"];
        readonly synonyms: readonly ["200-2100-0019", "Cinema", "Drive-in Theater", "Film Studio", "Indie Movie Theater", "Kino", "Movie Theater", "Multiplex", "movie_theater"];
    };
    readonly brothel: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["leisure"];
        readonly selectors: readonly ["amenity=brothel"];
        readonly synonyms: readonly ["200-2000-0306", "Adult Entertainment"];
    };
    readonly massage: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["leisure"];
        readonly selectors: readonly ["shop=massage"];
        readonly synonyms: readonly ["Bath House", "Massage Studio", "Spa", "spa"];
    };
    readonly playground: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["leisure"];
        readonly selectors: readonly ["leisure=playground", "playground=*"];
        readonly synonyms: readonly ["Indoor Play Area", "Playground", "Recreation Center", "recreation_center"];
    };
    readonly zoo: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["leisure"];
        readonly selectors: readonly ["tourism=zoo"];
        readonly synonyms: readonly ["550-5520-0208", "550-5520-0209", "550-5520-0210", "550-5520-0211", "550-5520-0228", "Animal Park", "Aquarium", "Wild Animal Park", "Wildlife Sanctuary", "Zoo Exhibit", "Zoo", "aquarium", "zoo"];
    };
    readonly casino: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["leisure"];
        readonly selectors: readonly ["amenity=casino"];
        readonly synonyms: readonly ["200-2300-0000", "200-2300-0021", "Casino", "casino"];
    };
    readonly stripclub: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["leisure"];
        readonly selectors: readonly ["amenity=stripclub"];
        readonly synonyms: readonly ["Strip Club"];
    };
    readonly park: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["leisure"];
        readonly selectors: readonly ["leisure=park", "leisure=garden", "amenity=park", "landuse=recreation_ground"];
        readonly synonyms: readonly ["550-5510-0202", "550-5510-0204", "Botanical Garden", "Botanischer Garten", "Garden", "National Park", "Outdoor Recreation", "Park oder Friedhof", "Park or Recreation Ground", "Park", "Ranger Station", "national_park", "park"];
    };
    readonly water_ramp: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["leisure"];
        readonly synonyms: readonly ["water_ramp"];
    };
    readonly sauna: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["leisure"];
        readonly selectors: readonly ["leisure=sauna"];
        readonly synonyms: readonly ["Sauna / Steam Room"];
    };
    readonly nightclub: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["leisure"];
        readonly selectors: readonly ["amenity=nightclub"];
        readonly synonyms: readonly ["Ballroom", "Country Dance Club", "Dance Studio", "Dive Bar", "Nightclub", "Other Nightlife", "night_club"];
    };
    readonly communitycentre: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["leisure"];
        readonly selectors: readonly ["amenity=community_centre"];
        readonly synonyms: readonly ["800-8100-0169", "800-8400-0000", "900-9200-0299", "Civic or Community Center", "Club House", "Collective Community", "Community Center", "Community College", "Convention Center", "Fair or Convention Facility", "Kongresshalle", "Kultursaal", "Meeting Room", "Social Club", "Turn-und Festhallen", "Wedding Hall", "city_hall", "community_centre"];
    };
    readonly health: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly synonyms: readonly ["700-7200-0272", "Healthcare & Support Services", "Medical School", "Santé", "health"];
    };
    readonly nursing_home: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["amenity=nursing_home", "healthcare=nursing_home", "healthcare=nursing"];
        readonly synonyms: readonly ["nursing", "nursing_agency"];
    };
    readonly retirement_home: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["amenity=retirement_home", "healthcare=retirement_home"];
    };
    readonly audiologist: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=audiologist"];
    };
    readonly birthing_centre: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=birthing_centre"];
    };
    readonly blood_bank: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=blood_bank"];
    };
    readonly blood_donation: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=blood_donation"];
    };
    readonly centre: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=centre"];
    };
    readonly clinic: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=clinic"];
    };
    readonly counselling: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=counselling"];
    };
    readonly dialysis: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=dialysis"];
    };
    readonly hospice: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=hospice"];
    };
    readonly laboratory: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=laboratory"];
    };
    readonly midwife: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=midwife"];
    };
    readonly rehabilitation: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=rehabilitation"];
    };
    readonly yes: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=yes", "healthcare:specialty=general"];
    };
    readonly ergotherapist: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=ergotherapist"];
    };
    readonly nutrition_counselling: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=nutrition_counselling"];
    };
    readonly podiatrist: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=podiatrist"];
    };
    readonly sample_collection: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=sample_collection"];
    };
    readonly vaccination_centre: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=vaccination_centre"];
    };
    readonly therapist: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=therapist"];
    };
    readonly allergology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=allergology"];
    };
    readonly anaesthetics: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=anaesthetics"];
    };
    readonly cardiology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=cardiology"];
    };
    readonly cardiothoracic_surgery: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=cardiothoracic_surgery"];
    };
    readonly child_psychiatry: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=child_psychiatry"];
    };
    readonly community: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=community"];
    };
    readonly dermatology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=dermatology"];
    };
    readonly dermatovenereology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=dermatovenereology"];
    };
    readonly diagnostic_radiology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=diagnostic_radiology"];
    };
    readonly emergency: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=emergency"];
    };
    readonly endocrinology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=endocrinology"];
    };
    readonly gastroenterology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=gastroenterology"];
    };
    readonly geriatrics: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=geriatrics"];
    };
    readonly gynaecology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=gynaecology"];
    };
    readonly haematology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=haematology"];
    };
    readonly hepatology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=hepatology"];
    };
    readonly infectious_diseases: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=infectious_diseases"];
    };
    readonly intensive: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=intensive"];
    };
    readonly internal: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=internal"];
    };
    readonly dental_oral_maxillo_facial_surgery: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=dental_oral_maxillo_facial_surgery"];
    };
    readonly neonatology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=neonatology"];
    };
    readonly nephrology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=nephrology"];
    };
    readonly neurology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=neurology"];
    };
    readonly neuropsychiatry: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=neuropsychiatry"];
    };
    readonly neurosurgery: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=neurosurgery"];
    };
    readonly nuclear: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=nuclear"];
    };
    readonly occupational: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=occupational"];
    };
    readonly oncology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=oncology"];
    };
    readonly ophthalmology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=ophthalmology"];
    };
    readonly orthodontics: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=orthodontics"];
    };
    readonly orthopaedics: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=orthopaedics"];
    };
    readonly otolaryngology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=otolaryngology"];
    };
    readonly paediatric_surgery: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=paediatric_surgery"];
    };
    readonly paediatrics: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=paediatrics"];
    };
    readonly palliative: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=palliative"];
    };
    readonly pathology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=pathology"];
    };
    readonly physiatry: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=physiatry"];
    };
    readonly plastic_surgery: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=plastic_surgery"];
    };
    readonly podiatry: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=podiatry"];
    };
    readonly proctology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=proctology"];
    };
    readonly psychiatry: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=psychiatry"];
    };
    readonly pulmonology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=pulmonology"];
    };
    readonly radiology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=radiology"];
    };
    readonly radiotherapy: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=radiotherapy"];
    };
    readonly rheumatology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=rheumatology"];
    };
    readonly stomatology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=stomatology"];
    };
    readonly surgery: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=surgery"];
    };
    readonly transplant: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=transplant"];
    };
    readonly trauma: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=trauma"];
    };
    readonly tropical: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=tropical"];
    };
    readonly urology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=urology"];
    };
    readonly vascular_surgery: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=vascular_surgery"];
    };
    readonly venereology: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=venereology"];
    };
    readonly abortion: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=abortion"];
    };
    readonly fertility: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=fertility"];
    };
    readonly vaccination: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare:specialty=vaccination"];
    };
    readonly physiotherapist: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=physiotherapist", "healthcare:speciality=physiotherapy"];
        readonly synonyms: readonly ["Physical Therapist", "physiotherapist", "physiotherapy_center"];
    };
    readonly hospital: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["amenity=hospital", "healthcare=hospital"];
        readonly synonyms: readonly ["700-7300-0280", "800-8000-0000", "800-8000-0157", "800-8000-0158", "800-8000-0159", "800-8000-0325", "800-8000-0367", "Accident & Emergency", "Ambulance Services", "Blood Bank", "Care Home", "Emergency Room", "Hospital or Health Care Facility", "Hospital", "Maternity Clinic", "Medical Center", "Medical Lab", "Medical Services or Clinic", "Rehab Center", "Spital oder Heim", "Urgent Care Center", "Ward", "hospital", "medical_lab"];
    };
    readonly dentist: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["amenity=dentist", "healthcare=dentist", "healthcare:speciality=dentistry"];
        readonly synonyms: readonly ["800-8000-0154", "Arzt- oder Zahnarztpraxis", "Dental Practice", "Dentist's Office", "dentist"];
    };
    readonly speech_therapist: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=speech_therapist"];
    };
    readonly pharmacy: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["amenity=pharmacy", "healthcare=pharmacy"];
        readonly synonyms: readonly ["600-6400-0000", "600-6400-0070", "Apotheke oder Drogerie", "Pharmacy", "Pharmacy/Drugs", "pharmacy"];
    };
    readonly psychotherapist: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=psychotherapist", "healthcare:speciality=psychotherapy", "healthcare=psychotherapy"];
        readonly synonyms: readonly ["800-8000-0156", "800-8000-0340", "Mental Health Office", "Psychiatric Institute", "Psychotherapy & Counseling"];
    };
    readonly hearing_aids: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["shop=hearing_aids", "healthcare=hearing_aids"];
    };
    readonly alternative_medicine: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=alternative", "healthcare=alternative_medicine"];
        readonly synonyms: readonly ["800-8000-0341", "Acupuncturist", "Alternative Healer", "Chiropractic", "Nutritionist", "alternative"];
    };
    readonly medical_store: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["shop=medical_supply", "healthcare=medical_store"];
        readonly synonyms: readonly ["Medical Supply Store", "Mobility Store", "medical_supply", "orthesist", "wheelchair_store"];
    };
    readonly social_facility: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["amenity=social_facility", "amenity=social_centre", "healthcare=social_facility", "healthcare=social_centre"];
        readonly synonyms: readonly ["700-7400-0147", "Assisted Living", "Home Service", "Social Services", "function_room_facility", "social_services_organization", "Soziokulturelles Zentrum"];
    };
    readonly occupational_therapist: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["healthcare=occupational_therapist"];
    };
    readonly ophthalmologist: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["shop=optician", "healthcare=optometrist"];
        readonly synonyms: readonly ["800-8000-0161", "Optical Shop", "Opticians", "optician"];
    };
    readonly doctor: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["health"];
        readonly selectors: readonly ["amenity=doctors", "healthcare=doctors", "healthcare=doctor"];
        readonly synonyms: readonly ["800-8000-0155", "800-8000-0162", "Doctor's Office", "Eye Doctor", "General Practicioners", "doctor", "doctors"];
    };
    readonly government: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly synonyms: readonly ["550-5510-0380", "700-7300-0113", "800-8100-0318", "900-9100-0214", "City", "Country", "County", "Lieu institutionnel", "Neighborhood", "State", "Town", "Village"];
    };
    readonly townhall: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["government"];
        readonly selectors: readonly ["amenity=townhall"];
        readonly synonyms: readonly ["800-8100-0163", "City Hall", "Town Hall"];
    };
    readonly court: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["government"];
        readonly selectors: readonly ["amenity=courthouse"];
        readonly synonyms: readonly ["800-8100-0170", "Courthouse", "courthouse"];
    };
    readonly political_party: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["government"];
        readonly selectors: readonly ["office=political_party"];
        readonly synonyms: readonly ["Campaign Office"];
    };
    readonly embassy: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["government"];
        readonly selectors: readonly ["amenity=embassy", "diplomatic=embassy", "office=diplomatic", "embassy=*"];
        readonly synonyms: readonly ["800-8100-0164", "Embassy / Consulate", "Embassy", "embassy"];
    };
    readonly employment_agency: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["government"];
        readonly selectors: readonly ["office=employment_agency"];
        readonly synonyms: readonly ["700-7200-0259", "700-7200-0267", "Human Resources & Recruiting Services", "Modeling Agency", "Recruiting Agency"];
    };
    readonly government_office: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["government"];
        readonly selectors: readonly ["office=government"];
        readonly synonyms: readonly ["700-7400-0289", "800-8100-0000", "800-8100-0165", "800-8100-0168", "800-8100-0171", "800-8100-0172", "800-8100-0317", "800-8700-0298", "Agricultural Checkpoint", "Border Crossing", "Business Center", "Business Service", "Capitol Building", "College Administrative Building", "County Council", "Fire Station", "Government Building", "Government Office", "Government or Community Facility", "Military Base", "Military Checkpoint", "Public Administration", "Registry Office", "States & Municipalities", "Verwaltung oder Amt", "Verwaltungsgebäude", "Voting Booth", "government", "government_office", "local_government_office"];
    };
    readonly police: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["government"];
        readonly selectors: readonly ["amenity=police"];
        readonly synonyms: readonly ["700-7300-0111", "700-7300-0112", "Police Station", "Policing & Security Services", "Polizei", "police", "police_department"];
    };
    readonly food: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly priority: 20;
        readonly synonyms: readonly ["100-1000-0003", "700-7200-0253", "700-7200-0258", "700-7400-0139", "Banqueting Hall", "Catering & Food Services", "College Cafeteria", "Corporate Cafeteria", "Food Production", "Kuruyemişçi", "Restaurant oder Café oder Bar", "Ski Lodge", "Takeaway and/or Delivery", "catering_service", "food", "meal_delivery"];
    };
    readonly restaurant: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["food"];
        readonly selectors: readonly ["amenity=restaurant"];
        readonly synonyms: readonly ["100-1000-0000", "100-1000-0001", "100-1000-0002", "100-1000-0005", "100-1000-0006", "100-1000-0008", "100-1000-0009", "100-1000-0230", "300-3000-0065", "Abruzzo Restaurant", "Acai House", "Acehnese Restaurant", "Afghan Restaurant", "African Restaurant", "Agriturismo", "Alsatian Restaurant", "American Restaurant", "Andhra Restaurant", "Anhui Restaurant", "Aosta Restaurant", "Apple Wine Pub", "Arepa Restaurant", "Argentinian Restaurant", "Ash and Haleem Place", "Asian Restaurant", "Australian Restaurant", "Austrian Restaurant", "Auvergne Restaurant", "Awadhi Restaurant", "BBQ Joint", "Baiano Restaurant", "Balinese Restaurant", "Basilicata Restaurant", "Basque Restaurant", "Bavarian Restaurant", "Beijing Restaurant", "Belarusian Restaurant", "Belgian Restaurant", "Bengali Restaurant", "Betawinese Restaurant", "Bistro", "Blini House", "Borek Place", "Bosnian Restaurant", "Bossam/Jokbal Restaurant", "Botanero", "Bougatsa Shop", "Brasserie", "Bratwurst Joint", "Brazilian Restaurant", "Breakfast Spot", "Breton Restaurant", "Buffet", "Bulgarian Restaurant", "Bunsik Restaurant", "Burgundian Restaurant", "Burmese Restaurant", "Burrito Place", "Cafeteria", "Cajun / Creole Restaurant", "Calabria Restaurant", "Cambodian Restaurant", "Campanian Restaurant", "Cantonese Restaurant", "Caribbean Restaurant", "Casual Dining", "Catalan Restaurant", "Caucasian Restaurant", "Central Brazilian Restaurant", "Ch'ti Restaurant", "Cha Chaan Teng", "Chaat Place", "Chettinad Restaurant", "Chinese Aristocrat Restaurant", "Chinese Breakfast Place", "Chinese Restaurant", "Churrascaria", "Cigkofte Place", "Colombian Restaurant", "Comfort Food Restaurant", "Corsican Restaurant", "Creperie", "Cretan Restaurant", "Cuban Restaurant", "Currywurst Joint", "Czech Restaurant", "Delicatessen", "Dhaba", "Dim Sum Restaurant", "Diner", "Dizi Place", "Donburi Restaurant", "Doner Restaurant", "Dongbei Restaurant", "Dosa Place", "Dumpling Restaurant", "Dutch Restaurant", "Eastern European Restaurant", "Emilia Restaurant", "Empada House", "Empanada Restaurant", "English Restaurant", "Estaminet", "Ethiopian Restaurant", "Falafel Restaurant", "Fast Food", "Filipino Restaurant", "Fine Dining", "Fish Taverna", "Fondue Restaurant", "Food", "Franconian Restaurant", "French Restaurant", "Friuli Restaurant", "Fujian Restaurant", "German Pop-Up Restaurant", "German Restaurant", "Gilaki Restaurant", "Gluten-free Restaurant", "Goan Restaurant", "Goiano Restaurant", "Gozleme Place", "Greek Restaurant", "Grilled Meat Restaurant", "Guizhou Restaurant", "Gujarati Restaurant", "Gukbap Restaurant", "Hainan Restaurant", "Hakka Restaurant", "Halal Restaurant", "Hawaiian Restaurant", "Hawker Centre", "Henan Restaurant", "Himalayan Restaurant", "Hong Kong Restaurant", "Hotpot Restaurant", "Huaiyang Restaurant", "Hubei Restaurant", "Hunan Restaurant", "Hungarian Restaurant", "Hyderabadi Restaurant", "Imperial Restaurant", "Indian Chinese Restaurant", "Indian Restaurant", "Indian Sweet Shop", "Indonesian Meatball Place", "Indonesian Restaurant", "Irani Cafe", "Israeli Restaurant", "Italian Restaurant", "Jain Restaurant", "Janguh Restaurant", "Japanese Curry Restaurant", "Japanese Restaurant", "Javanese Restaurant", "Jegaraki", "Jewish Restaurant", "Jiangsu Restaurant", "Jiangxi Restaurant", "Kaiseki BistroRestaurant", "Karnataka Restaurant", "Kebab Restaurant", "Kerala Restaurant", "Kofte Place", "Kokoreç Restaurant", "Korean Restaurant", "Kosher Restaurant", "Kumpir Restaurant", "Kumru Restaurant", "Kurdish Restaurant", "Kushikatsu Restaurant", "Labour Canteen", "Latin American Restaurant", "Lebanese Restaurant", "Ligurian Restaurant", "Lombard Restaurant", "Lyonese Bouchon", "Mac & Cheese Joint", "Macanese Restaurant", "Magirio", "Maharashtrian Restaurant", "Malay Restaurant", "Malga", "Manadonese Restaurant", "Manchu Restaurant", "Manti Place", "Marche Restaurant", "Mediterranean Restaurant", "Mexican Restaurant", "Meyhane", "Meze Restaurant", "Middle Eastern Restaurant", "Mineiro Restaurant", "Modern European Restaurant", "Modern Greek Restaurant", "Molecular Gastronomy Restaurant", "Molise Restaurant", "Mongolian Restaurant", "Monjayaki Restaurant", "Moroccan Restaurant", "Mughlai Restaurant", "Multicuisine Indian Restaurant", "Nabe Restaurant", "New American Restaurant", "Noodle House", "Norman Restaurant", "North Indian Restaurant", "Northeast Indian Restaurant", "Northeastern Brazilian Restaurant", "Northern Brazilian Restaurant", "Okonomiyaki Restaurant", "Ouzeri", "Padangnese Restaurant", "Paella Restaurant", "Pakistani Restaurant", "Palatine Restaurant", "Parsi Restaurant", "Pastelaria", "Patsa Restaurant", "Peking Duck Restaurant", "Pelmeni House", "Persian Restaurant", "Peruvian Restaurant", "Piadineria", "Pide Place", "Piedmontese Restaurant", "Pilavcı", "Polish Restaurant", "Portuguese Restaurant", "Poutine Place", "Provençal Restaurant", "Puglia Restaurant", "Punjabi Restaurant", "Rajasthani Restaurant", "Ramen Restaurant", "Restaurant", "Rhenisch Restaurant", "Romagna Restaurant", "Roman Restaurant", "Romanian Restaurant", "Russian Restaurant", "Salad Place", "Salvadoran Restaurant", "Samgyetang Restaurant", "Sandwich Place", "Sardinian Restaurant", "Satay Restaurant", "Savoyard Restaurant", "Scandinavian Restaurant", "Schnitzel Restaurant", "Scottish Restaurant", "Seafood Restaurant", "Shaanxi Restaurant", "Shabu-Shabu Restaurant", "Shandong Restaurant", "Shanghai Restaurant", "Shanxi Restaurant", "Sicilian Restaurant", "Silesian Restaurant", "Slovak Restaurant", "Snack Place", "Soba Restaurant", "Som Tum Restaurant", "Soup Place", "South American Restaurant", "South Indian Restaurant", "South Tyrolean Restaurant", "Southeastern Brazilian Restaurant", "Southern / Soul Food Restaurant", "Southern Brazilian Restaurant", "Southwestern French Restaurant", "Spanish Restaurant", "Sri Lankan Restaurant", "Steakhouse", "Sukiyaki Restaurant", "Sundanese Restaurant", "Sushi Restaurant", "Swabian Restaurant", "Swiss Restaurant", "Szechuan Restaurant", "Söğüş Place", "Tabbakhi", "Taco Place", "Taiwanese Restaurant", "Takoyaki Place", "Tantuni Restaurant", "Tapas Restaurant", "Tapiocaria", "Taqueria", "Tatar Restaurant", "Tempura Restaurant", "Tex-Mex Restaurant", "Thai Restaurant", "Theme Restaurant", "Tianjin Restaurant", "Tibetan Restaurant", "Tonkatsu Restaurant", "Trattoria/Osteria", "Trentino Restaurant", "Truck Stop", "Tsipouro Restaurant", "Turkish Home Cooking Restaurant", "Turkish Restaurant", "Tuscan Restaurant", "Udon Restaurant", "Udupi Restaurant", "Ukrainian Restaurant", "Umbrian Restaurant", "Unagi Restaurant", "Varenyky restaurant", "Vegetarian / Vegan Restaurant", "Veneto Restaurant", "Venezuelan Restaurant", "Vietnamese Restaurant", "Wagashi Place", "West-Ukrainian Restaurant", "Xinjiang Restaurant", "Yakitori Restaurant", "Yoshoku Restaurant", "Yucatecan Restaurant", "Yunnan Restaurant", "Zhejiang Restaurant", "restaurant", "Çöp Şiş Place"];
    };
    readonly canteen: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["food"];
        readonly selectors: readonly ["amenity=canteen"];
    };
    readonly coffee: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["food"];
        readonly selectors: readonly ["amenity=cafe"];
        readonly synonyms: readonly ["100-1000-0007", "100-1100-0000", "100-1100-0010", "700-7400-0285", "700-7900-0132", "Café", "Coffee & Tea", "Coffee Shop", "Corporate Coffee Shop", "Internet Cafe", "Kafenio", "Pet Café", "Transport Cafe/Services", "Turkish Coffeehouse", "cafe", "internet_cafe"];
    };
    readonly pub: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["food"];
        readonly selectors: readonly ["amenity=pub"];
        readonly synonyms: readonly ["Apres Ski Bar", "Irish Pub", "Pub", "bar"];
    };
    readonly fastfood: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["food"];
        readonly selectors: readonly ["amenity=fast_food", "amenity=food_court"];
        readonly synonyms: readonly ["Burger Joint", "Fast Food Restaurant", "Fish & Chips Shop", "Food Court", "Food Stand", "Food Truck", "Fried Chicken Joint", "Friterie", "Gastropub", "Hot Dog Joint", "Juice Bar", "Pizza Place", "Street Food Gathering", "Wings Joint", "fast_food", "fast_food_restaurant", "meal_takeaway"];
    };
    readonly bar: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["food", "leisure"];
        readonly selectors: readonly ["amenity=bar"];
        readonly synonyms: readonly ["200-2000-0000", "200-2000-0011", "200-2000-0012", "200-2000-0013", "200-2000-0014", "200-2000-0368", "300-3000-0350", "300-3000-0351", "Bar or Pub", "Bar", "Beach Bar", "Beer Bar", "Brewery", "Champagne Bar", "Club", "Cocktail Bar", "Cocktail Lounge", "Dance Hall or Studio", "Gay Bar", "Hookah Bar", "Hotel Bar", "Jazz Club", "Karaoke Bar", "Karaoke Box", "Karaoke", "Lounge", "Music Festival", "Music Venue", "Night Club", "Nightlife & Entertainment", "Nightlife Spot", "Nuit", "Piano Bar", "Rock Club", "Sake Bar", "Speakeasy", "Sports Bar", "Tiki Bar", "Whisky Bar", "Wine Bar"];
    };
    readonly icecream: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["food"];
        readonly selectors: readonly ["amenity=ice_cream"];
        readonly synonyms: readonly ["Frozen Yogurt Shop", "Ice Cream Shop", "ice_cream"];
    };
    readonly biergarten: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["food"];
        readonly selectors: readonly ["amenity=biergarten"];
        readonly synonyms: readonly ["Beer Garden"];
    };
    readonly drinkingwater: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["food"];
        readonly selectors: readonly ["amenity=drinking_water"];
        readonly synonyms: readonly ["drinking_water"];
    };
    readonly education: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly synonyms: readonly ["training_center", "800-8200-0000", "Education Facility", "Grund- oder Mittel- oder Berufs- oder Fach- oder Hochschule", "education"];
    };
    readonly music_school: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["education"];
        readonly selectors: readonly ["amenity=music_school"];
        readonly synonyms: readonly ["Music School"];
    };
    readonly driving_school: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["education"];
        readonly selectors: readonly ["amenity=driving_school"];
        readonly synonyms: readonly ["driving_school", "Driving School"];
    };
    readonly school: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["education"];
        readonly selectors: readonly ["amenity=school"];
        readonly synonyms: readonly ["800-8200-0174", "800-8200-0295", "800-8200-0360", "800-8200-0361", "800-8200-0362", "Coaching Centre", "Elementary School", "Fine Arts Training", "Language Education", "Preschool", "School", "Schulen", "Trade School", "Training & Development", "elementary_school", "school"];
    };
    readonly kindergarten: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["education"];
        readonly selectors: readonly ["amenity=childcare", "amenity=kindergarten"];
        readonly synonyms: readonly ["700-7400-0286", "Child Care Service", "Daycare", "Kinderbetreuung", "Kindergärten", "Nursery & Childcare", "child_care_agency"];
    };
    readonly university: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["education"];
        readonly selectors: readonly ["amenity=university"];
        readonly synonyms: readonly ["800-8200-0173", "General College & University", "Higher Education", "University"];
    };
    readonly college: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["education"];
        readonly selectors: readonly ["amenity=college"];
        readonly synonyms: readonly ["Adult Education Center", "Auditorium", "College & University", "College Academic Building", "College Arts Building", "College Auditorium", "College Classroom", "College Communications Building", "College Engineering Building", "College History Building", "College Lab", "College Math Building", "College Quad", "College Science Building", "College Technology Building", "Cooking School", "Flight School", "High School", "Language School", "Middle School", "Nursery School", "Private School", "Student Center", "college", "high_school", "middle_school"];
    };
    readonly culture: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly synonyms: readonly ["Concert Hall", "Cultural Center", "200-2300-0022", "Kultur und Soziales"];
    };
    readonly museum: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["culture", "leisure", "tourism", "education"];
        readonly selectors: readonly ["tourism=museum"];
        readonly synonyms: readonly ["museum", "Museum", "Art Museum", "History Museum", "Planetarium", "Science Museum", "Observatory", "Historic Site", "Children's Museum", "300-3100-0026", "300-3100-0027", "300-3100-0028", "300-3100-0029", "300-3100-0000", "Musée"];
    };
    readonly library: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["culture"];
        readonly selectors: readonly ["amenity=library"];
        readonly synonyms: readonly ["library", "Library", "Other library", "800-8300-0000", "800-8300-0175", "Bibliothek"];
    };
    readonly arts_center: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["culture"];
        readonly selectors: readonly ["amenity=arts_centre"];
        readonly synonyms: readonly ["300-3000-0024", "800-8400-0176", "Art Studio", "Convention or Exhibition Centre", "Exhibit", "Gallery", "arts_centre", "cultural_center"];
    };
    readonly public_art: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["culture"];
        readonly selectors: readonly ["tourism=artwork"];
        readonly synonyms: readonly ["Outdoor Sculpture", "Public Art", "Sculpture Garden", "Street Art", "artwork"];
    };
    readonly art_gallery: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["culture"];
        readonly selectors: readonly ["tourism=gallery"];
        readonly synonyms: readonly ["Art Gallery", "Museum oder Galerie", "art_gallery", "gallery"];
    };
    readonly place_of_worship: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["culture"];
        readonly selectors: readonly ["amenity=place_of_worship"];
        readonly synonyms: readonly ["300-3200-0000", "300-3200-0030", "300-3200-0031", "300-3200-0032", "300-3200-0033", "300-3200-0034", "300-3200-0309", "300-3200-0375", "Ashram", "Buddhist Temple", "Cemevi", "Church", "Confucian Temple", "Friedhof", "Gurdwara", "Hindu Temple", "Kingdom Hall", "Monastery", "Mosque", "Place of Worship", "Prayer Room", "Religious Place", "Religious School", "Shrine", "Spiritual Center", "Spiritualité", "Synagogue", "Temple", "Terreiro", "cemetery", "church", "hindu_temple", "mosque", "place_of_worship", "synagogue"];
    };
    readonly theater: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["culture"];
        readonly selectors: readonly ["amenity=theatre"];
        readonly synonyms: readonly ["200-2200-0000", "200-2200-0020", "Amphitheater", "College Theater", "Indie Theater", "Konzerthalle oder Oper oder Theatersaal", "Music & Culture", "Opera House", "Performing Arts Centre", "Performing Arts Venue", "Theater", "Theatre", "opera_house", "performing_arts_theater", "theatre"];
    };
    readonly accommodation: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly synonyms: readonly ["500-5000-0000", "900-9300-0221", "Hotel or Motel", "Hébergement", "Residential Building (Apartment / Condo)", "Residential Building", "accommodation"];
        readonly priority: 50;
    };
    readonly bed_breakfast: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["accommodation"];
        readonly selectors: readonly ["tourism=bed_and_breakfast"];
        readonly synonyms: readonly ["500-5100-0058", "Bed & Breakfast", "bed_and_breakfast"];
    };
    readonly dormitory: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["accommodation"];
        readonly selectors: readonly ["building=dormitory"];
        readonly synonyms: readonly ["Boarding House", "College Residence Hall", "Fraternity House", "Residence", "Sorority House", "vacation_appartment"];
    };
    readonly motel: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["accommodation"];
        readonly selectors: readonly ["tourism=motel"];
        readonly synonyms: readonly ["500-5000-0054", "Motel"];
    };
    readonly chalet: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["accommodation"];
        readonly selectors: readonly ["tourism=chalet"];
        readonly synonyms: readonly ["500-5100-0354", "Hütte", "Mountain Huts", "Ski Chalet", "Trekking Hut", "gite"];
    };
    readonly caravan_site: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["accommodation"];
        readonly selectors: readonly ["tourism=caravan_site"];
        readonly synonyms: readonly ["rv_park", "RV Park", "Trailer Park"];
    };
    readonly hotel: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["accommodation"];
        readonly selectors: readonly ["tourism=hotel"];
        readonly synonyms: readonly ["500-5000-0053", "500-5100-0000", "500-5100-0060", "550-5520-0212", "Hotel oder Pension oder Bed & Breakfast", "Hotel", "Lodging", "Short-time Hotel", "Ski Resort", "hotel", "lodging", "luxury_hotel"];
    };
    readonly camping: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["accommodation"];
        readonly selectors: readonly ["tourism=camp_site"];
        readonly synonyms: readonly ["500-5100-0056", "500-5100-0059", "550-5510-0378", "Campground", "Campingplatz", "Campsite", "Holiday Camp", "camp_site", "campground"];
    };
    readonly guest_house: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["accommodation"];
        readonly selectors: readonly ["tourism=guest_house"];
        readonly synonyms: readonly ["500-5100-0057", "Ferienhaus oder Ferienwohnung", "Gruppenunterkünfte", "Guest House", "Vacation Rental", "indoor_lodging"];
    };
    readonly hostel: {
        readonly name: () => string;
        readonly icon: FunctionComponent<SVGProps<SVGSVGElement> & {
        title?: string;
        }>;
        readonly parents: readonly ["accommodation"];
        readonly selectors: readonly ["tourism=hostel"];
        readonly synonyms: readonly ["500-5100-0055", "Hostel", "hostel"];
    };
};

export declare type Category = keyof typeof categories;

export declare type CategoryBaseProperties = {
    name: () => string;
    icon?: FC;
    hide?: boolean;
    priority?: number;
    parents?: Readonly<Category[]>;
    selectors?: Readonly<Array<OsmTagValuePair>>;
    synonyms?: Readonly<Array<string>>;
};

export declare type CategoryProperties = CategoryBaseProperties & {
    id: Category;
};

/**
 * Returns category "unknown" if no match was found.
 */
export declare function findCategoryByOSMTags(osmTags: Record<string, string>): CategoryProperties;

export declare function findCategoryBySynonym(synonym?: string): CategoryProperties;

/**
 * Returns a SQL `CASE WHEN ... END` statement that can be used to query a category from OSM tags.
 * If your OSM tags are stored in a JSON column, you can pass the column name as the second argument.
 * If not, it assumes the tags are stored as regular columns in the table. The statement falls back
 * to category "unknown" if no match was found.
 */
export declare function generateCategoryByOSMTagsSQLStatement(tableName: string, jsonColumnName?: string): string;

export declare function getCategories(): Record<Category, CategoryBaseProperties>;

export declare function getChildCategories(parent: Category): Partial<Record<Category, CategoryBaseProperties>>;

export declare function getPrioritizedSelectorList(): SelectorList;

export declare function getSelectorMap(): Map<OsmTagValuePair, {
    category: Category;
    specificity: number;
}>;

export declare function getSynonymMap(): Map<string, Category>;

export declare function getTopLevelCategories(): Partial<Record<Category, CategoryBaseProperties>>;

export declare type OsmTagValuePair = `${string}=${string}`;

declare type SelectorList = [
OsmTagValuePair,
    {
    category: Category;
    specificity: number;
}
][];

export declare const setTranslator: (givenTranslator: (category: string) => string) => void;

export { }
